@@ -43,12 +43,12 @@ KEYS = [
     ('X1MB',),
     ('X2MB',),
     (),
-    ('\b',),
-    ('\t',),
+    ('\b', 'BACKSPACE'),
+    ('\t', 'TAB'),
     (),
     (),
     ('CLEAR',),
-    ('\n',),
+    ('\n', 'ENTER'),
     (),
     (),
     ('SHIFT',),
@@ -67,7 +67,7 @@ KEYS = [
     ('IMENONCONVERT',),
     ('IMEACCEPT',),
     ('IMEMODECHANGE',),
-    (' ',),
+    (' ', 'SPACE'),
     ('PAGEUP',),
     ('PAGEDOWN',),
     ('END',),
@@ -307,7 +307,8 @@ GMEM_ZEROINIT = 0x0040
 
 
 def _key_to_vk(key):
-    key = key.strip().upper()
+    if key != ' ':
+        key = key.strip(' ').upper()
     try:
         return KEY_MAP[key]
     except KeyError:
@@ -376,14 +377,15 @@ def _parse_pos(x, y):
     if rel:
         x = x.imag or x.real
         y = y.imag or y.real
+    else:
+        if not (0.0 < x < 1.0 or 0.0 < y < 1.0):
+            w, h = size()
+            x /= w
+            y /= h
 
-    if not (0.0 < x < 1.0 or 0.0 < y < 1.0):
-        w, h = size()
-        x /= w
-        y /= h
+        x *= MAX
+        y *= MAX
 
-    x *= MAX
-    y *= MAX
     return int(x), int(y), rel
 
 
@@ -604,7 +606,7 @@ def click(*args):
         button = MB.parse(args[0])
     elif argc == 2:
         x, y = args
-        button = MB.parse(args[0])
+        button = MB.L
         # TODO move mouse with the call directly
         move(x, y)
     elif argc == 3:
@@ -747,14 +749,14 @@ def events():
 # Mouse-keyboard common
 
 
-def holding(vk):
+def holding(key):
     """
     https://docs.microsoft.com/en-us/windows/desktop/api/winuser/nf-winuser-getkeystate
     SHORT GetKeyState(
         int nVirtKey
     );
     """
-    return (ctypes.windll.user32.GetKeyState(vk) & 0x80) != 0
+    return (ctypes.windll.user32.GetKeyState(_key_to_vk(key)) & 0x80) != 0
 
 
 def color(x, y):
